@@ -183,12 +183,16 @@ class Div(Directive):
                     error_handler=(self.state.document.settings.\
                                    input_encoding_error_handler),
                     handle_io_errors=None)
-            except IOError, error:
+            except IOError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 raise self.severe('Problems with "%s" directive path:\n%s.'
                                   % (self.name, error))
             try:
                 text = raw_file.read()
-            except UnicodeError, error:
+            except UnicodeError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 raise self.severe(
                     'Problem with "%s" directive:\n%s: %s'
                     % (self.name, error.__class__.__name__, error))
@@ -202,7 +206,9 @@ class Div(Directive):
             import urllib2
             try:
                 raw_text = urllib2.urlopen(source).read()
-            except (urllib2.URLError, IOError, OSError), error:
+            except (urllib2.URLError, IOError, OSError):
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 raise self.severe(
                     'Problems with "%s" directive URL "%s":\n%s.'
                     % (self.name, self.options['url'], error))
@@ -212,7 +218,9 @@ class Div(Directive):
                                input_encoding_error_handler))
             try:
                 text = raw_file.read()
-            except UnicodeError, error:
+            except UnicodeError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 raise self.severe(
                     'Problem with "%s" directive:\n%s: %s'
                     % (self.name, error.__class__.__name__, error))
@@ -230,7 +238,9 @@ class Div(Directive):
                 lines = statemachine.string2lines(
                     text, tab_width, convert_whitespace=1)
                 text = '\n'.join(lines[startline:endline])
-        except UnicodeError, error:
+        except UnicodeError:
+            (t, error, tb) = sys.exc_info()
+            del(tb)
             raise self.severe(
                 'Problem with "%s" directive:\n%s: %s'
                 % (self.name, error.__class__.__name__, error))
@@ -471,7 +481,9 @@ class DivX(Div):
                     error_handler=(self.state.document.settings.\
                                    input_encoding_error_handler),
                     handle_io_errors=None)
-            except IOError, error:
+            except IOError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     '||:div:||', 'error' ))
@@ -479,7 +491,9 @@ class DivX(Div):
                                   % (self.name, error))
             try:
                 text = raw_file.read()
-            except UnicodeError, error:
+            except UnicodeError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     '||:div:||', 'error' ))
@@ -496,7 +510,9 @@ class DivX(Div):
             import urllib2
             try:
                 raw_text = urllib2.urlopen(source).read()
-            except (urllib2.URLError, IOError, OSError), error:
+            except (urllib2.URLError, IOError, OSError):
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     '||:div:||', 'error' ))
@@ -509,7 +525,9 @@ class DivX(Div):
                                input_encoding_error_handler))
             try:
                 text = raw_file.read()
-            except UnicodeError, error:
+            except UnicodeError:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     '||:div:||', 'error' ))
@@ -530,7 +548,9 @@ class DivX(Div):
                 lines = statemachine.string2lines(
                     text, tab_width, convert_whitespace=1)
                 text = '\n'.join(lines[startline:endline])
-        except UnicodeError, error:
+        except UnicodeError:
+            (t, error, tb) = sys.exc_info()
+            del(tb)
             sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     '||:div:||', 'error' ))
@@ -641,14 +661,16 @@ class DivX(Div):
             div_node = nodes.div('', *[], **attributes)
             try:
                 self.state.nested_parse(content, offset, div_node, 1)
-            except Exception as e:
+            except Exception:
+                (t, error, tb) = sys.exc_info()
+                del(tb)
                 sys.stderr.write( "# {1:<{0}s}: [{2!r}]\n".format(
                         dbg_fwid if 'dbg_fwid' in globals() else 15,
-                        e.__class__.__name__, dir(e)))
+                        error.__class__.__name__, dir(e)))
                 sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                         dbg_fwid if 'dbg_fwid' in globals() else 15,
                         '||:div:||', 'error below' ))
-                raise e
+                raise error
             sys.stderr.write( "# {1:<{0}s}: [{2!s}]\n".format(
                     dbg_fwid if 'dbg_fwid' in globals() else 15,
                     'children', div_node.children ))
@@ -716,6 +738,7 @@ docutils.parsers.rst.directives._directive_registry[ 'divx' ] = ('misc', 'DivX')
 
 # :ide: COMPILE: Run w/o args
 # . (progn (save-buffer) (compile (concat "python ./" (file-name-nondirectory (buffer-file-name)) " ")))
+
 #
 # Local Variables:
 # mode: python
